@@ -3,7 +3,7 @@ from typing import List, Optional
 
 import pandas as pd
 from pydantic import BaseModel
-from pydantic.class_validators import validator
+from pydantic.class_validators import validator, root_validator
 from pydantic.fields import Field
 
 from exodusutils import internal
@@ -37,6 +37,13 @@ class TrainReqBodyBase(BaseModel):
             )
         return v
 
+    @root_validator
+    def validate_header(cls, values):
+        data = values["training_data"].decode("utf-8")
+        header = data.split("\n")[0].split(",")
+        internal.validate_columns(header, values["feature_types"])
+        return values
+
     def get_feature_names(self) -> List[str]:
         """
         Returns the names of the features.
@@ -104,11 +111,15 @@ class PredictReqBody(BaseModel):
         """
         Returns the Pandas DataFrame from the bytes in data field.
         """
-        return pd.DataFrame(pd.read_json(self.data, orient="records")).pipe(
+        df = pd.DataFrame(pd.read_json(self.data, orient="records"))
+
+        # Check if all of the columns necessary for prediction are present in the dataframe
+        internal.validate_columns(df.columns, feature_types)
+
+        return df.pipe(
             internal.cast_df_types, feature_types
         )
 
-
 class MigrateAction(str, Enum):
     """
     Defines the migration action. Could only be either one of `up` and `down`.
