@@ -1,6 +1,6 @@
 from typing import Any, Dict, List, Optional
 
-from pydantic import BaseModel, validator
+from pydantic import BaseModel
 from pydantic.fields import Field
 
 from exodusutils.schemas import Attribute
@@ -42,13 +42,3 @@ class InfoRespBody(BaseModel):
 
     name: str = Field(description="Name of the model algorithm")
     description: str = Field(description="Description of the model algorithm")
-    compatible_groupby_methods: List[str] = Field(
-        default=["standard"],
-        description="List of compatible groupby method names. Must contain at least 1 element",
-    )
-
-    @validator("compatible_groupby_methods")
-    def check_groupby_methods(cls, v):
-        if not v:
-            raise ValueError("No compatible groupby method found")
-        return v
